@@ -14,6 +14,7 @@ import java.util.Vector;
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.TreeViewColumnEvent;
 import org.gnu.gtk.event.TreeViewColumnListener;
@@ -32,7 +33,7 @@ public class TreeViewColumn extends GObject {
 
 	/**
 	 */
-	protected TreeViewColumn(int handle) {
+	protected TreeViewColumn(Handle handle) {
 		super(handle);
 	}
 
@@ -67,15 +68,14 @@ public class TreeViewColumn extends GObject {
 	/**
 	 * Returns an array of CellRenderers in the column in no particular
 	 * order.
-	 * @return
 	 */
 	public CellRenderer[] getCellRenderers() {
-		int[] hndls = gtk_tree_view_column_get_cell_renderers(getHandle());
+	    Handle[] hndls = gtk_tree_view_column_get_cell_renderers(getHandle());
 		if (null == hndls)
 			return null;
 		CellRenderer[] cr = new CellRenderer[hndls.length];
 		for (int i = 0; i < hndls.length; i++) {
-			GObject obj = retrieveGObject(hndls[i]);
+			GObject obj = getGObjectFromHandle(hndls[i]);
 			if (null != obj)
 				cr[i] = (CellRenderer)obj;
 			else
@@ -231,10 +231,10 @@ public class TreeViewColumn extends GObject {
 	}
 	
 	public Widget getWidget() {
-		int hndl = gtk_tree_view_column_get_widget(getHandle());
-		if (0 == hndl)
+	    Handle hndl = gtk_tree_view_column_get_widget(getHandle());
+		if (null == hndl)
 			return null;
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
@@ -269,9 +269,9 @@ public class TreeViewColumn extends GObject {
 	}
 
 	/**
-	 * Sets the logical sortColumnId that this column sorts on when this column 
+	 * Sets the logical DataColumn that this column sorts on when this column 
 	 * is selected for sorting. Doing so makes the column header clickable.
-	 * @param sortColumnId The sortColumnId of the model to sort on.
+	 * @param column The DataColumn of the model to sort on.
 	 */
 	public void setSortColumn( DataColumn column ) {
 		gtk_tree_view_column_set_sort_column_id(getHandle(), column.getColumn() );
@@ -293,17 +293,20 @@ public class TreeViewColumn extends GObject {
 
 	/**
 	 * Changes the appearance of the sort indicator.
-	 *
-	 * <p>This does not actually sort the model. Use {@link #setSortColumnID(int)}
-	 * if you want automatic sorting support. This function is primarily for 
+	 * <p>
+	 * This does not actually sort the model. Use 
+         * {@link #setSortColumn} if you want automatic sorting 
+         * support. This function is primarily for 
 	 * custom sorting behavior, and should be used in conjunction with 
-	 * {@link #setSortColumnID(int)} to do that. For custom models, the mechanism will 
-	 * vary.
-	 * 
-	 * <p>The sort indicator changes direction to indicate normal sort or 
-	 * reverse sort. Note that you must have the sort indicator enabled to see 
-	 * anything when calling this function; 
+	 * {@link #setSortColumn} to do that. 
+         * For custom models, the mechanism will vary.
+	 * <p>
+	 * The sort indicator changes direction to indicate normal sort or 
+	 * reverse sort. Note that you must have the sort indicator enabled 
+         * to see anything when calling this function; 
+         * 
 	 * @see #setSortIndicator(boolean)
+         * @see #setSortColumn
 	 * @param order Sort order that the sort indicator should indicate
 	 */
 	public void setSortOrder(SortType order) {
@@ -466,56 +469,50 @@ public class TreeViewColumn extends GObject {
 		return new Type(gtk_tree_view_column_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF JNI CODE
-	 ****************************************/
 	native static final protected int gtk_tree_view_column_get_type();
-	native static final protected int gtk_tree_view_column_new();
-	native static final protected void gtk_tree_view_column_pack_start(int treeColumn, int cell, boolean expand);
-	native static final protected void gtk_tree_view_column_pack_end(int treeColumn, int cell, boolean expand);
-	native static final protected void gtk_tree_view_column_clear(int treeColumn);
-	native static final protected int[] gtk_tree_view_column_get_cell_renderers(int treeColumn);
-	native static final protected void gtk_tree_view_column_add_attribute(int treeColumn, int cellRenderer, String attribute, int column);
-	native static final protected void gtk_tree_view_column_clear_attributes(int treeColumn, int cellRenderer);
-	native static final protected void gtk_tree_view_column_set_spacing(int treeColumn, int spacing);
-	native static final protected int gtk_tree_view_column_get_spacing(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_visible(int treeColumn, boolean visible);
-	native static final protected boolean gtk_tree_view_column_get_visible(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_resizable(int treeColumn, boolean resizable);
-	native static final protected boolean gtk_tree_view_column_get_resizable(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_sizing(int treeColumn, int type);
-	native static final protected int gtk_tree_view_column_get_sizing(int treeColumn);
-	native static final protected int gtk_tree_view_column_get_width(int treeColumn);
-	native static final protected int gtk_tree_view_column_get_fixed_width(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_fixed_width(int treeColumn, int fixedWidth);
-	native static final protected void gtk_tree_view_column_set_min_width(int treeColumn, int minWidth);
-	native static final protected int gtk_tree_view_column_get_min_width(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_max_width(int treeColumn, int maxWidth);
-	native static final protected int gtk_tree_view_column_get_max_width(int treeColumn);
-	native static final protected void gtk_tree_view_column_clicked(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_title(int treeColumn, String title);
-	native static final protected String gtk_tree_view_column_get_title(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_expand(int treeColumn, boolean expand);
-	native static final protected boolean gtk_tree_view_column_get_expand(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_clickable(int treeColumn, boolean clickable);
-	native static final protected boolean gtk_tree_view_column_get_clickable(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_widget(int treeColumn, int widget);
-	native static final protected int gtk_tree_view_column_get_widget(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_alignment(int treeColumn, double xalign);
-	native static final protected double gtk_tree_view_column_get_alignment(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_reorderable(int treeColumn, boolean reorderable);
-	native static final protected boolean gtk_tree_view_column_get_reorderable(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_sort_column_id(int treeColumn, int sortColumnID);
-	native static final protected int gtk_tree_view_column_get_sort_column_id(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_sort_indicator(int treeColumn, boolean setting);
-	native static final protected boolean gtk_tree_view_column_get_sort_indicator(int treeColumn);
-	native static final protected void gtk_tree_view_column_set_sort_order(int treeColumn, int order);
-	native static final protected int gtk_tree_view_column_get_sort_order(int treeColumn);
-	native static final protected void gtk_tree_view_column_cell_set_cell_data(int treeColumn, int treeModel, int iter, boolean isExpander, boolean isExpanded);
-	native static final protected void gtk_tree_view_column_cell_get_size(int treeColumn, int[] cellArea, int[] xOffset, int[] yOffset, int[] width, int[] height);
-	native static final protected boolean gtk_tree_view_column_cell_is_visible(int treeColumn);
-	native static final protected void gtk_tree_view_column_focus_cell(int treeColumn, int cell);
-	/****************************************
-	 * END OF JNI CODE
-	 ****************************************/
+	native static final protected Handle gtk_tree_view_column_new();
+	native static final protected void gtk_tree_view_column_pack_start(Handle treeColumn, Handle cell, boolean expand);
+	native static final protected void gtk_tree_view_column_pack_end(Handle treeColumn, Handle cell, boolean expand);
+	native static final protected void gtk_tree_view_column_clear(Handle treeColumn);
+	native static final protected Handle[] gtk_tree_view_column_get_cell_renderers(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_add_attribute(Handle treeColumn, Handle cellRenderer, String attribute, int column);
+	native static final protected void gtk_tree_view_column_clear_attributes(Handle treeColumn, Handle cellRenderer);
+	native static final protected void gtk_tree_view_column_set_spacing(Handle treeColumn, int spacing);
+	native static final protected int gtk_tree_view_column_get_spacing(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_visible(Handle treeColumn, boolean visible);
+	native static final protected boolean gtk_tree_view_column_get_visible(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_resizable(Handle treeColumn, boolean resizable);
+	native static final protected boolean gtk_tree_view_column_get_resizable(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_sizing(Handle treeColumn, int type);
+	native static final protected int gtk_tree_view_column_get_sizing(Handle treeColumn);
+	native static final protected int gtk_tree_view_column_get_width(Handle treeColumn);
+	native static final protected int gtk_tree_view_column_get_fixed_width(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_fixed_width(Handle treeColumn, int fixedWidth);
+	native static final protected void gtk_tree_view_column_set_min_width(Handle treeColumn, int minWidth);
+	native static final protected int gtk_tree_view_column_get_min_width(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_max_width(Handle treeColumn, int maxWidth);
+	native static final protected int gtk_tree_view_column_get_max_width(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_clicked(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_title(Handle treeColumn, String title);
+	native static final protected String gtk_tree_view_column_get_title(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_expand(Handle treeColumn, boolean expand);
+	native static final protected boolean gtk_tree_view_column_get_expand(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_clickable(Handle treeColumn, boolean clickable);
+	native static final protected boolean gtk_tree_view_column_get_clickable(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_widget(Handle treeColumn, Handle widget);
+	native static final protected Handle gtk_tree_view_column_get_widget(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_alignment(Handle treeColumn, double xalign);
+	native static final protected double gtk_tree_view_column_get_alignment(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_reorderable(Handle treeColumn, boolean reorderable);
+	native static final protected boolean gtk_tree_view_column_get_reorderable(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_sort_column_id(Handle treeColumn, int sortColumnID);
+	native static final protected int gtk_tree_view_column_get_sort_column_id(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_sort_indicator(Handle treeColumn, boolean setting);
+	native static final protected boolean gtk_tree_view_column_get_sort_indicator(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_set_sort_order(Handle treeColumn, int order);
+	native static final protected int gtk_tree_view_column_get_sort_order(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_cell_set_cell_data(Handle treeColumn, Handle treeModel, Handle iter, boolean isExpander, boolean isExpanded);
+	native static final protected void gtk_tree_view_column_cell_get_size(Handle treeColumn, Handle cellRectangle, int[] xOffset, int[] yOffset, int[] width, int[] height);
+	native static final protected boolean gtk_tree_view_column_cell_is_visible(Handle treeColumn);
+	native static final protected void gtk_tree_view_column_focus_cell(Handle treeColumn, Handle cell);
 }
